summaryrefslogtreecommitdiff
path: root/coverage/control.py
diff options
context:
space:
mode:
authorNed Batchelder <ned@nedbatchelder.com>2009-12-26 08:49:00 -0500
committerNed Batchelder <ned@nedbatchelder.com>2009-12-26 08:49:00 -0500
commit04076715a642d0caa6436e81d35416e711b80d52 (patch)
tree4e8a7c8af5f61e07b78970fc8a587e363de5db6e /coverage/control.py
parentfa62e0238a631ce0d1894ebe6311bd7c2aee0298 (diff)
downloadpython-coveragepy-git-04076715a642d0caa6436e81d35416e711b80d52.tar.gz
COVERAGE_PROCESS_START now is the name of the rc file, and we use it to measure our own coverage.
Diffstat (limited to 'coverage/control.py')
-rw-r--r--coverage/control.py8
1 files changed, 3 insertions, 5 deletions
diff --git a/coverage/control.py b/coverage/control.py
index 415df277..94cb931f 100644
--- a/coverage/control.py
+++ b/coverage/control.py
@@ -382,15 +382,13 @@ def process_startup():
import coverage; coverage.process_startup()
If the environment variable COVERAGE_PROCESS_START is defined, coverage
- measurement is started. The value of the variable is the data file
- prefix to use.
+ measurement is started. The value of the variable is the config file
+ to use.
"""
cps = os.environ.get("COVERAGE_PROCESS_START")
if cps:
- cov = coverage(
- auto_data=True, data_file=cps, data_suffix=True, branch=True
- )
+ cov = coverage(config_file=cps, auto_data=True, data_suffix=True)
if os.environ.get("COVERAGE_COVERAGE"):
# Measuring coverage within coverage.py takes yet more trickery.
cov.cover_prefix = "Please measure coverage.py!"